@@ -3,7 +3,7 @@ All configurations for pyconch
 """
 
 
-from pytconf.config import Config, ParamCreator
+from pytconf import Config, ParamCreator
 
 
 class ConfigDummy(Config):
